import { EvmContract } from './evm-contract';
/**
 * The provider manages the web3 calls to a endpoint, however the LoomProvider
 * wraps the web3 call which intent to be sent to an Ethereum node and turn it
 * into a Loom call for a Loom Contract
 */
export declare class LoomProvider {
    protected contract: EvmContract;
    /**
     * @param contract: The contract which wraps an ethereum EVM
     */
    constructor(contract: EvmContract);
    _callAsync(data: string): Promise<any>;
    _callStaticAsync(data: string): Promise<any>;
    _okResponse(result?: any): any;
    /**
     * Should be used to make async request
     * This method is used internally by web3, so we adapt it to be used with loom contract
     * when we are wrapping the evm on a DAppChain
     * @param payload JSON payload generated by web3 which will be translated to loom transaction/call
     * @param callback Triggered on end with (err, result)
     */
    send(payload: any, callback: Function): any;
}
